@@ -5,7 +5,7 @@ __email__ = 'robbert@xkls.nl'
 __licence__ = 'GPL v3'
 
 
-from ybe import read_ybe_file, YbeToQTI_1p2
+from ybe import read_ybe_file, YbeToQTI_v1p2
 from importlib import resources
 
 # read the provided example Ybe.
@@ -16,4 +16,4 @@ with resources.path('ybe.data', 'example_database.ybe') as path:
 output_dir = '/tmp/qti_output/'
 
 # Write a QTI with the equations converted to the way Canvas (https://canvas.instructure.com) likes it.
-YbeToQTI_1p2(convert_canvas_equations=True).convert(ybe_exam, output_dir + 'new.zip')
+YbeToQTI_v1p2(convert_canvas_equations=True).convert(ybe_exam, output_dir + 'new.zip')
